/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.common;

import java.net.URL;

/**
 * This singleton class is responsible for the dynamic loading of classes.
 * Unlike a normal <code>URLClassLoader</code> it is possible to dynamically add
 * and remove urls from the class loader. This instance should always be used if
 * plugin objects have to be created.
 * 
 * @author Nils Christian Ehmke
 */
public final class PluginClassLoader {

	/**
	 * The singleton instance of this class.
	 */
	private static final PluginClassLoader INSTANCE = new PluginClassLoader();

	/**
	 * The default constructor of this class.
	 */
	private PluginClassLoader() {
		// Nothing to do
	}

	/**
	 * This method can be used to add an url to the class loader.
	 * 
	 * @param fileName
	 *            The file name of the dependency to be added.
	 */
	public void addURL(final String fileName) {
		// TODO Implement
	}

	/**
	 * This method can be used to remove an url from the class loader.
	 * 
	 * @param fileName
	 *            The file name of the dependency to be removed.
	 */
	public void removeURL(final String fileName) {
		// TODO Implement
	}

	/**
	 * Delivers the only instance of this class.
	 * 
	 * @return The singleton instance of this class.
	 */
	public static final synchronized PluginClassLoader getInstance() {
		return PluginClassLoader.INSTANCE;
	}

	/**
	 * This method tries to load the class with the given name using the
	 * currently loaded dependencies.
	 * 
	 * @param name
	 *            The name of the class to be loaded.
	 * @return The class.
	 */
	public Class<?> loadClass(final String name) {
		// TODO Implement
		return null;
	}
}
